/*
 * $Id: rb_polygon.c 38 2004-07-25 11:27:25Z tilman $
 *
 * Copyright (C) 2004 Tilman Sauerbeck (tilman at code-monkey de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <ruby.h>

#include <Evas.h>

#include "rb_evas_main.h"
#include "rb_evas.h"
#include "rb_evas_object.h"

static VALUE c_new (VALUE klass, VALUE evas)
{
	VALUE self, argv[1];
	Evas_Object **rect;

	CHECK_CLASS (evas, cEvas);
	GET_OBJ (evas, Evas *, e);

	self = Data_Make_Struct (klass, Evas_Object *, c_evas_object_mark,
	                         c_evas_object_free, rect);
	*rect = evas_object_polygon_add (*e);

	argv[0] = evas;
	rb_obj_call_init (self, 1, argv);

	return self;
}

static VALUE c_point_add (VALUE self, VALUE x, VALUE y)
{
	GET_OBJ (self, Evas_Object *, e);

	Check_Type (x, T_FIXNUM);
	Check_Type (y, T_FIXNUM);

	evas_object_polygon_point_add (*e, FIX2INT (x), FIX2INT (y));

	return Qnil;
}

static VALUE c_points_clear (VALUE self)
{
	GET_OBJ (self, Evas_Object *, e);

	evas_object_polygon_points_clear (*e);

	return Qnil;
}

void Init_Polygon (void)
{
	VALUE c = rb_define_class_under (mEvas, "Polygon", cEvasObject);

	rb_define_singleton_method (c, "new", c_new, 1);
	rb_define_method (c, "point_add", c_point_add, 2);
	rb_define_method (c, "points_clear", c_points_clear, 0);
}
